%bcond_with tests
%bcond_with doc

%global sname oslo.config
%global pypi_name oslo-config

Summary:    OpenStack common configuration library
Name:       python-oslo-config
Version:    9.0.0
Release:    7%{?dist}
License:    ASL 2.0
URL:        https://launchpad.net/%{sname}
Source0:    https://tarballs.openstack.org/%{sname}/%{sname}-%{version}.tar.gz

BuildArch:  noarch

%description
The Oslo project intends to produce a python library containing infrastructure code shared by
OpenStack projects. The APIs provided by the project should be high quality, stable, consistent and generally useful.

The oslo-config library is a command line and configuration file parsing library from the Oslo project.

%package -n python3-%{pypi_name}
Summary:  OpenStack common configuration library
BuildRequires: python3-devel python3-setuptools python3-oslo-i18n python3-rfc3986 python3-pbr
BuildRequires: git-core python3-requests-mock python3-netaddr python3-stevedore python3-PyYAML
%if %{with tests}
BuildRequires: python3-testscenarios python3-stestr python3-testtools python3-oslotest
%endif
Requires: python3-oslo-i18n python3-rfc3986 python3-pbr python3-requests python3-stevedore
Requires: python3-netaddr python3-yaml python3-debtcollector

%description -n python3-%{pypi_name}
The Oslo project intends to produce a python library containing infrastructure code shared by
OpenStack projects. The APIs provided by the project should be high quality, stable, consistent and
generally useful.

The oslo-config library is a command line and configuration file parsing library from the Oslo project.

%if %{with doc}
%package -n python-%{pypi_name}-doc
Summary:    Documentation for OpenStack common configuration library
BuildRequires: python3-sphinx python3-fixtures python3-openstackdocstheme
BuildRequires: python3-oslotest python3-debtcollector python3-stevedore python3-sphinxcontrib-apidoc

%description -n python-%{pypi_name}-doc
Documentation for the oslo-config library.
%endif

%prep
%autosetup -n %{sname}-%{version} -S git
sed -i '/\/usr\/bin\/env/d' oslo_config/validator.py
rm -rf {test-,}requirements.txt

%if %{with doc}
rm oslo_config/tests/test_sphinxext.py
rm oslo_config/tests/test_sphinxconfiggen.py
%endif

%build
%{py3_build}

%if %{with doc}
export PYTHONPATH=.
sphinx-build-3 -b html doc/source doc/build/html
rm -rf doc/build/html/.{doctrees,buildinfo}
%endif

%install
%{py3_install}
pushd %{buildroot}/%{_bindir}
    for i in generator validator
    do
        ln -s oslo-config-$i oslo-config-$i-3
    done
popd

%check
%if %{with tests}
PYTHON=python3 stestr-3 run --black-regex test_generator_raises_error
%endif

%files -n python3-%{pypi_name}
%license LICENSE
%doc README.rst
%{_bindir}/oslo-config-generator
%{_bindir}/oslo-config-generator-3
%{_bindir}/oslo-config-validator
%{_bindir}/oslo-config-validator-3
%{python3_sitelib}/oslo_config
%{python3_sitelib}/*.egg-info

%if %{with doc}
%files -n python-%{pypi_name}-doc
%license LICENSE
%doc doc/build/html
%endif

%changelog
* Thu Sep 26 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 9.0.0-7
- Rebuilt for clarifying the packages requirement in BaseOS and AppStream

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 9.0.0-6
- Rebuilt for loongarch release

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 9.0.0-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 9.0.0-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 9.0.0-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 9.0.0-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 29 2023 Shuo Wang <abushwang@tencent.com> - 9.0.0-1
- initial build
